@@ -71,7 +71,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_control_object = NULL;
 
 G_DEFINE_TYPE (GpmControl, gpm_control, G_TYPE_OBJECT)
@@ -253,6 +253,37 @@ gpm_control_allowed_reboot (GpmControl *control,
 	return TRUE;
 }
 
+/* convert the HAL error to a local error */
+static void
+gpm_control_convert_hal_error (GpmControl *control,
+			       GError    **error)
+{
+	gint code;
+	gchar *message;
+	if (error == NULL) {
+		return;
+	}
+
+	/* copy out the needed data */
+	code = (*error)->code;
+	message = g_strdup ((*error)->message);
+
+	/* clear the old HAL error */
+	g_error_free (*error);
+	*error = NULL;
+
+	/* localize */
+	if (code == 9) {
+		/* DBUS security prevents sending */
+		g_set_error (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL,
+			     _("The message was not sent due to DBUS security rules"));
+	} else {
+		g_set_error (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL,
+			     _("General failure: %s"), message);
+	}
+	g_free (message);
+}
+
 /**
  * gpm_control_shutdown:
  * @control: This class instance
@@ -285,8 +316,11 @@ gpm_control_shutdown (GpmControl *control,
 					   GNOME_SAVE_GLOBAL,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 	}
-	hal_gpower_shutdown (control->priv->hal_power);
-	ret = TRUE;
+
+	ret = hal_gpower_shutdown (control->priv->hal_power, error);
+	if (ret == FALSE) {
+		gpm_control_convert_hal_error (control, error);
+	}
 
 	return ret;
 }
@@ -302,7 +336,6 @@ gpm_control_reboot (GpmControl *control,
 		    GError    **error)
 {
 	gboolean allowed;
-	gboolean ret;
 	gboolean save_session;
 
 	gpm_control_allowed_reboot (control, &allowed, error);
@@ -324,10 +357,7 @@ gpm_control_reboot (GpmControl *control,
 					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 	}
 
-	hal_gpower_reboot (control->priv->hal_power);
-	ret = TRUE;
-
-	return ret;
+	return hal_gpower_reboot (control->priv->hal_power, error);
 }
 
 /**
@@ -381,13 +411,13 @@ gpm_control_suspend (GpmControl *control,
 		g_set_error (error,
 			     GPM_CONTROL_ERROR,
 			     GPM_CONTROL_ERROR_GENERAL,
-			     "Cannot suspend");
+			     "Cannot suspend as not allowed from policy");
 		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_SUSPEND);
 		return FALSE;
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING, &lock_gnome_keyring);
+	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_SUSPEND, &lock_gnome_keyring);
 	if (lock_gnome_keyring == TRUE) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
@@ -408,7 +438,12 @@ gpm_control_suspend (GpmControl *control,
 	/* Do the suspend */
 	gpm_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
-	ret = hal_gpower_suspend (control->priv->hal_power, 0);
+
+	ret = hal_gpower_suspend (control->priv->hal_power, 0, error);
+	if (ret == FALSE) {
+		gpm_control_convert_hal_error (control, error);
+	}
+
 	gpm_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
 
@@ -460,7 +495,7 @@ gpm_control_hibernate (GpmControl *control,
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING, &lock_gnome_keyring);
+	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_HIBERNATE, &lock_gnome_keyring);
 	if (lock_gnome_keyring == TRUE) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
@@ -480,7 +515,12 @@ gpm_control_hibernate (GpmControl *control,
 
 	gpm_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
-	ret = hal_gpower_hibernate (control->priv->hal_power);
+
+	ret = hal_gpower_hibernate (control->priv->hal_power, error);
+	if (ret == FALSE) {
+		gpm_control_convert_hal_error (control, error);
+	}
+
 	gpm_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
